@@ -1,4 +1,4 @@
-__version__ = "0.1.6"
-import eagerx_pybullet.bridge  # noqa # pylint: disable=unused-import
+__version__ = "0.1.8"
+import eagerx_pybullet.engine  # noqa # pylint: disable=unused-import
 import eagerx_pybullet.enginenodes  # noqa # pylint: disable=unused-import
 import eagerx_pybullet.enginestates  # noqa # pylint: disable=unused-import
